ExtendFootprintTtlOperation

Struct ExtendFootprintTtlOperation 

pub struct ExtendFootprintTtlOperation { /* private fields */ }
Represents an operation to extend the footprint TTL for Soroban (smart contract) related ledger entries.

Soroban introduces temporary ledger entries with a TTL (time to live) that can be extended. This operation sets the TTL of all entries in the transaction’s footprint to at least extend_to (a ledger sequence number). If an entry already exceeds this value, it is unaffected.

NOTE: The ext field in ExtendFootprintTtlOp is currently always the empty ExtensionPoint::V0.

Implementations

Source

impl ExtendFootprintTtlOperation

pub fn source_account(&self) -> &Option<MuxedAccount>

Retrieves the operation source account.

pub fn source_account_mut(&mut self) -> &mut Option<MuxedAccount>

Retrieves a mutable reference to the operation source account.

pub fn extend_to(&self) -> &u32

Retrieves the target ledger sequence number to extend TTLs to.

pub fn extend_to_mut(&mut self) -> &mut u32

Retrieves a mutable reference to the target ledger sequence number.

pub fn to_xdr_operation_body(&self) -> Result<OperationBody>

Returns the XDR operation body.

pub fn from_xdr_operation_body( source_account: Option<MuxedAccount>, x: &ExtendFootprintTtlOp, ) -> Result<ExtendFootprintTtlOperation>

Creates from the XDR operation body.