InvokeHostFunctionOperation

Struct InvokeHostFunctionOperation 

pub struct InvokeHostFunctionOperation { /* private fields */ }
Represents an operation invoking a Soroban host function.

Soroban smart contracts are accessed through host functions that are executed atomically within the context of the transaction. This operation carries:

  • The host function (one of:
    • InvokeContract
    • CreateContract
    • UploadContractWasm
    • CreateContractV2 )
  • Authorization entries proving the required signatures / invocation authorizations

The XDR struct backing this is:

struct InvokeHostFunctionOp {
    HostFunction hostFunction;
    SorobanAuthorizationEntry auth<>;
};

Implementations

Source

impl InvokeHostFunctionOperation

pub fn source_account(&self) -> &Option<MuxedAccount>

Source account (if any) overriding the transaction source.

pub fn source_account_mut(&mut self) -> &mut Option<MuxedAccount>

Mutable reference to the source account.

pub fn host_function(&self) -> &HostFunction

The host function to invoke.

pub fn host_function_mut(&mut self) -> &mut HostFunction

Mutable reference to the host function.

pub fn auth(&self) -> &[SorobanAuthorizationEntry]

Authorization entries.

pub fn auth_mut(&mut self) -> &mut Vec<SorobanAuthorizationEntry>

Mutable authorization entries.

pub fn to_xdr_operation_body(&self) -> Result<OperationBody>

Returns the XDR operation body.

pub fn from_xdr_operation_body( source_account: Option<MuxedAccount>, x: &InvokeHostFunctionOp, ) -> Result<InvokeHostFunctionOperation>

Creates from the XDR operation body.