PathPaymentStrictReceiveOperation

Struct PathPaymentStrictReceiveOperation 

pub struct PathPaymentStrictReceiveOperation { /* private fields */ }

Implementations

Source

impl PathPaymentStrictReceiveOperation

pub fn source_account(&self) -> &Option<MuxedAccount>

Retrieves the operation source account.

pub fn source_account_mut(&mut self) -> &mut Option<MuxedAccount>

Retrieves a reference to the operation source account.

pub fn destination(&self) -> &MuxedAccount

Retrieves the operation destination.

pub fn destination_mut(&mut self) -> &mut MuxedAccount

Retrieves a mutable reference to the operation destination.

pub fn send_asset(&self) -> &Asset

Retrieves the operatino send asset.

pub fn send_asset_mut(&mut self) -> &mut Asset

Retrieves a mutable reference to the operatino send asset.

pub fn send_max(&self) -> &Stroops

Retrieves the operation send max.

pub fn send_max_mut(&mut self) -> &mut Stroops

Retrieves a mutable reference to the operation send max.

pub fn destination_asset(&self) -> &Asset

Retrieves the operation destination asset.

pub fn destination_asset_mut(&mut self) -> &mut Asset

Retrieves a mutable reference to the operation destination asset.

pub fn destination_amount(&self) -> &Stroops

Retrieves the operation destination amount.

pub fn destination_amount_mut(&mut self) -> &mut Stroops

Retrieves a mutable reference to the operation destination amount.

pub fn path(&self) -> &Vec<Asset>

Retrieves the operation path.

pub fn path_mut(&mut self) -> &mut Vec<Asset>

Retrieves a mutable reference to the operation path.

pub fn to_xdr_operation_body(&self) -> Result<OperationBody>

Returns the xdr operation body.

pub fn from_xdr_operation_body( source_account: Option<MuxedAccount>, x: &PathPaymentStrictReceiveOp, ) -> Result<PathPaymentStrictReceiveOperation>

Creates from the xdr operation body.