SetOptionsOperation

Struct SetOptionsOperation 

pub struct SetOptionsOperation { /* private fields */ }

Implementations

Source

impl SetOptionsOperation

pub fn source_account(&self) -> &Option<MuxedAccount>

Retrieves the operation source account.

pub fn source_account_mut(&mut self) -> &mut Option<MuxedAccount>

Retrieves a reference to the operation source account.

pub fn inflation_destination(&self) -> &Option<PublicKey>

Retrieves the operation inflation destination.

pub fn inflation_destination_mut(&mut self) -> &mut Option<PublicKey>

Retrieves a mutable reference to the operation inflation destination.

pub fn clear_flags(&self) -> &Option<AccountFlags>

Retrieves the operation clear flags.

pub fn clear_flags_mut(&mut self) -> &mut Option<AccountFlags>

Retrieves a mutable reference to the operation clear flags.

pub fn set_flags(&self) -> &Option<AccountFlags>

Retrieves the operation set flags.

pub fn set_flags_mut(&mut self) -> &mut Option<AccountFlags>

Retrieves a mutable reference to the operation set flags.

pub fn master_weight(&self) -> &Option<u32>

Retrieves the operation master weight.

pub fn master_weight_mut(&mut self) -> &mut Option<u32>

Retrieves a mutable reference to the operation master weight.

pub fn low_threshold(&self) -> &Option<u32>

Retrieves the operation low threshold.

pub fn low_threshold_mut(&mut self) -> &mut Option<u32>

Retrieves a mutable reference to the operation low threshold.

pub fn medium_threshold(&self) -> &Option<u32>

Retrieves the operation medium threshold.

pub fn medium_threshold_mut(&mut self) -> &mut Option<u32>

Retrieves a mutable reference to the operation medium threshold.

pub fn high_threshold(&self) -> &Option<u32>

Retrieves the operation high threshold.

pub fn high_threshold_mut(&mut self) -> &mut Option<u32>

Retrieves a mutable reference to the operation high threshold.

pub fn home_domain(&self) -> &Option<String>

Retrieves the operation home domain.

pub fn home_domain_mut(&mut self) -> &mut Option<String>

Retrieves a mutable reference to the operation home domain.

pub fn signer(&self) -> &Option<Signer>

Retrieves the operation signer.

pub fn signer_mut(&mut self) -> &mut Option<Signer>

Retrieves a mutable reference the operation signer.

pub fn to_xdr_operation_body(&self) -> Result<OperationBody>

Returns the xdr operation body.

pub fn from_xdr_operation_body( source_account: Option<MuxedAccount>, x: &SetOptionsOp, ) -> Result<SetOptionsOperation>

Creates from the xdr operation body.