[−][src]Struct stellar_base::signature::Signature
A signature.
Implementations
impl Signature[src]
pub fn sign(secret: &SecretKey, data: &[u8]) -> Signature[src]
Signs data using the secret key.
pub fn from_slice(sb: &[u8]) -> Result<Signature>[src]
Returns a Signature from bytes.
pub fn len(&self) -> usize[src]
Length in bytes of the signature.
pub fn is_empty(&self) -> bool[src]
Returns true if the signature has no bytes.
pub fn to_vec(&self) -> Vec<u8>[src]
Convert to Vec<u8>.
pub fn as_bytes(&self) -> &[u8][src]
Inner buffer as slice.
pub fn verify(&self, public: &PublicKey, data: &[u8]) -> bool[src]
Verifise the signature againt the data and the public key.
Returns true if the signature is valid, false otherwise.
pub fn to_xdr(&self) -> Result<Signature>[src]
Returns xdr object.
pub fn from_xdr(x: &Signature) -> Result<Signature>[src]
Creates from xdr object.