FeeBumpTransaction

Struct FeeBumpTransaction 

pub struct FeeBumpTransaction { /* private fields */ }
Fee bump transaction.

Implementations

Source

impl FeeBumpTransaction

pub fn new( fee_source: MuxedAccount, fee: Stroops, inner_tx: Transaction, ) -> FeeBumpTransaction

Creates a new fee bump transaction.

pub fn fee_source(&self) -> &MuxedAccount

Retrieves the transaction fee source.

pub fn fee_source_mut(&mut self) -> &mut MuxedAccount

Retrieves a mutable reference to the transaction fee source.

pub fn fee(&self) -> &Stroops

Retrievies the transaction fee.

pub fn fee_mut(&mut self) -> &mut Stroops

Retrievies a mutable reference to the transaction fee.

pub fn inner_transaction(&self) -> &Transaction

Retrieves the transaction inner transaction.

pub fn inner_transaction_mut(&mut self) -> &mut Transaction

Retrieves a mutable reference to the transaction inner transaction.

pub fn signatures(&self) -> &Vec<DecoratedSignature>

Retrieves the transaction signatures.

pub fn signatures_mut(&mut self) -> &mut Vec<DecoratedSignature>

Retrieves a mutable reference the transaction signatures.

pub fn into_envelope(self) -> TransactionEnvelope

Creates a TransactionEnvelope from the transaction.

This consumes the transaction and takes ownership of it.

pub fn to_envelope(&self) -> TransactionEnvelope

Creates a TransactionEnvelope from the transaction.

pub fn sign_hashx(&mut self, preimage: &[u8]) -> Result<()>

Sign transaction with preimage, and add signature.

This signs the transaction with the preimage x of hash(x).

pub fn sign<S, V>( &mut self, key: &KeyPair<S, V>, network: &Network, ) -> Result<()>

Sign transaction with key for network, and add signature.

pub fn decorated_signature_from_preimage( &self, preimage: &[u8], ) -> Result<DecoratedSignature>

Returns the decorated signature of the transaction create with image.

pub fn decorated_signature<S, V>( &self, key: &KeyPair<S, V>, network: &Network, ) -> Result<DecoratedSignature>

Returns the decorated signature of the transaction create with key for network.

pub fn hash(&self, network: &Network) -> Result<Vec<u8>>

Returns the transaction hash for the transaction on network.

pub fn signature_data(&self, network: &Network) -> Result<Vec<u8>>

Returns the transaction signature data as bytes.

pub fn to_xdr(&self) -> Result<FeeBumpTransaction>

Returns the xdr object.

pub fn to_xdr_envelope(&self) -> Result<FeeBumpTransactionEnvelope>

Returns the fee bump transaction envelope xdr object.

pub fn from_xdr(x: &FeeBumpTransaction) -> Result<FeeBumpTransaction>

Creates from xdr object.

pub fn from_xdr_envelope( x: &FeeBumpTransactionEnvelope, ) -> Result<FeeBumpTransaction>

Creates from xdr envelope object.

pub fn to_xdr_transaction_signature_payload( &self, network: &Network, ) -> Result<TransactionSignaturePayload>

Returns the xdr transaction signature payload object.