Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }
Stellar transaction.

Implementations

Source

impl Transaction

pub fn builder<S: Into<MuxedAccount>>( source_account: S, sequence: i64, fee: Stroops, ) -> TransactionBuilder

Creates a TransactionBuilder to configure a Transaction.

This is the same as TransactionBuilder::new.

pub fn source_account(&self) -> &MuxedAccount

Retrieves the transaction source account.

pub fn source_account_mut(&mut self) -> &mut MuxedAccount

Retrieves a mutable reference to the transaction source account.

pub fn fee(&self) -> &Stroops

Retrieves the transaction fee.

pub fn fee_mut(&mut self) -> &mut Stroops

Retrieves a mutable reference to the transaction fee.

pub fn sequence(&self) -> &i64

Retrieves the transaction sequence number.

pub fn sequence_mut(&mut self) -> &mut i64

Retrieves a mutable reference to the transaction sequence number.

pub fn time_bounds(&self) -> &Option<TimeBounds>

Retrieves the transaction time bounds.

pub fn time_bounds_mut(&mut self) -> &mut Option<TimeBounds>

Retrieves a mutable reference to the transaction time bounds.

pub fn memo(&self) -> &Memo

Retrieves the transaction memo.

pub fn memo_mut(&mut self) -> &mut Memo

Retrieves a mutable reference to the transaction memo.

pub fn operations(&self) -> &Vec<Operation>

Retrieves the transaction operations.

pub fn operations_mut(&mut self) -> &mut Vec<Operation>

Retrieves a mutable reference to the transaction operations.

pub fn signatures(&self) -> &Vec<DecoratedSignature>

Retrieves the transaction signatures.

pub fn signatures_mut(&mut self) -> &mut Vec<DecoratedSignature>

Retrieves a mutable reference to the transaction signatures.

pub fn to_envelope(&self) -> TransactionEnvelope

Creates a TransactionEnvelope from the transaction.

pub fn into_envelope(self) -> TransactionEnvelope

Creates a TransactionEnvelope from the transaction.

This consumes the transaction and takes ownership of it.

pub fn sign_hashx(&mut self, preimage: &[u8]) -> Result<()>

Sign transaction with preimage, and add signature.

This signs the transaction with the preimage x of hash(x).

pub fn sign<S, V>( &mut self, key: &KeyPair<S, V>, network: &Network, ) -> Result<()>

Sign transaction with key for network, and add signature.

pub fn decorated_signature_from_preimage( &self, preimage: &[u8], ) -> Result<DecoratedSignature>

Returns the decorated signature of the transaction create with image.

pub fn decorated_signature<S, V>( &self, key: &KeyPair<S, V>, network: &Network, ) -> Result<DecoratedSignature>

Returns the decorated signature of the transaction create with key for network.

pub fn hash(&self, network: &Network) -> Result<Vec<u8>>

Returns the transaction hash for the transaction on network.

pub fn signature_data(&self, network: &Network) -> Result<Vec<u8>>

Returns the transaction signature data as bytes.

pub fn to_xdr(&self) -> Result<Transaction>

Returns the xdr object.

pub fn to_xdr_envelope(&self) -> Result<TransactionV1Envelope>

Returns the transaction envelope v1 xdr object.

pub fn to_xdr_transaction_signature_payload( &self, network: &Network, ) -> Result<TransactionSignaturePayload>

Returns the xdr transaction signature payload object.

pub fn from_xdr_v0(x: &TransactionV0) -> Result<Transaction>

Creates from v0 xdr object.

pub fn from_xdr(x: &Transaction) -> Result<Transaction>

Creates from xdr object.

pub fn from_xdr_v0_envelope(x: &TransactionV0Envelope) -> Result<Transaction>

Creates from xdr v0 envelope object.

pub fn from_xdr_envelope(x: &TransactionV1Envelope) -> Result<Transaction>

Creates from xdr envelope object.