pub struct LedgerKeyClaimableBalance {
pub balance_id: ClaimableBalanceId,
}Expand description
LedgerKeyClaimableBalance is an XDR NestedStruct defines as:
struct
{
ClaimableBalanceID balanceID;
}Fields
balance_id: ClaimableBalanceIdTrait Implementations
Sourceimpl Clone for LedgerKeyClaimableBalance
impl Clone for LedgerKeyClaimableBalance
Sourcefn clone(&self) -> LedgerKeyClaimableBalance
fn clone(&self) -> LedgerKeyClaimableBalance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LedgerKeyClaimableBalance
impl Debug for LedgerKeyClaimableBalance
Sourceimpl Default for LedgerKeyClaimableBalance
impl Default for LedgerKeyClaimableBalance
Sourcefn default() -> LedgerKeyClaimableBalance
fn default() -> LedgerKeyClaimableBalance
Returns the “default value” for a type. Read more
impl Eq for LedgerKeyClaimableBalance
Sourceimpl From<LedgerKeyClaimableBalance> for LedgerKey
impl From<LedgerKeyClaimableBalance> for LedgerKey
Sourcefn from(key: LedgerKeyClaimableBalance) -> LedgerKey
fn from(key: LedgerKeyClaimableBalance) -> LedgerKey
Converts to this type from the input type.
Sourceimpl Hash for LedgerKeyClaimableBalance
impl Hash for LedgerKeyClaimableBalance
Sourceimpl Ord for LedgerKeyClaimableBalance
impl Ord for LedgerKeyClaimableBalance
Sourcefn cmp(&self, other: &LedgerKeyClaimableBalance) -> Ordering
fn cmp(&self, other: &LedgerKeyClaimableBalance) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LedgerKeyClaimableBalance
impl PartialEq for LedgerKeyClaimableBalance
Sourcefn eq(&self, other: &LedgerKeyClaimableBalance) -> bool
fn eq(&self, other: &LedgerKeyClaimableBalance) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LedgerKeyClaimableBalance
impl PartialOrd for LedgerKeyClaimableBalance
Sourceimpl ReadXdr for LedgerKeyClaimableBalance
impl ReadXdr for LedgerKeyClaimableBalance
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<LedgerKeyClaimableBalance, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<LedgerKeyClaimableBalance, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
impl StructuralPartialEq for LedgerKeyClaimableBalance