pub trait Name {
// Required method
fn name(&self) -> &'static str;
}Expand description
Name defines types that assign a static name to their value, such as the name given to an identifier in an XDR enum, or the name given to the case in a union.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".